@@ -27,14 +27,14 @@
  * @brief  Select folder dialog.
  *
  * @param[in]  gw_parent  Dialog parent widget
- * @return  Foler path or NULL.
+ * @return     Foler path or NULL.
  */
 char *
 add_images_folder_dialog (GtkWindow *gw_parent)
 {
     GtkWidget  *gw_dialog;
-    char       *s_folder  = NULL;
-    int         res       = 0;
+    char       *s_folder  = NULL; /* Result selected folder string */
+    int         res       = 0;    /* Dialog run response */
 
     gw_dialog = gtk_file_chooser_dialog_new ("Select Folder",
                                           gw_parent,
@@ -57,15 +57,15 @@ add_images_folder_dialog (GtkWindow *gw_parent)
  * @brief  Select images dialog.
  *
  * @param[in]  gw_parent  Dialog parent widget
- * @return  List with images.
+ * @return     List with images.
  */
 GSList *
 add_images_dialog (GtkWindow *gw_parent)
 {
-    GSList        *gsl_files = NULL;
+    GSList        *gsl_files = NULL; /* Result file list */
     GtkFileFilter *gff_filter;
     GtkWidget     *gw_dialog;
-    int            res       = 0;
+    int            res       = 0;    /* Dialog run response */
 
     gw_dialog = gtk_file_chooser_dialog_new ("Select Files",
                                           gw_parent,
