@@ -24,11 +24,14 @@
 #ifndef MISCFUN_H
 #define MISCFUN_H
 #include <stdio.h>
-#include <gmodule.h>
+#include <glib.h>
+#include <dirent.h> 
 #include "settstr.h"
 /*----------------------------------------------------------------------------*/
 uint64_t hash(const char *str);
 /*----------------------------------------------------------------------------*/
+char *get_file_ext (char *s_fn);
+/*----------------------------------------------------------------------------*/
 int read_file_data (const char *s_fname, char **s_buff);
 /*----------------------------------------------------------------------------*/
 int save_file_data (const char *s_fname, const char *s_buff);
@@ -40,4 +43,6 @@ int my_gslist_get_position (GSList *gsl_list, const char *s_what);
 int read_file_data_hash (const char *s_fname, char **s_buff,
                          uint64_t *i_hash);
 /*----------------------------------------------------------------------------*/
+GSList *get_directory_content (const char *s_path1);
+/*----------------------------------------------------------------------------*/
 #endif
