@@ -1,26 +1,26 @@
 /**
- * @file  settstr.h
- * @copyright Copyright (C) 2019 Michał Bąbik
- *
- * This file is part of Wall Changer.
- *
- * Wall Changer is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Wall Changer is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Wall Changer.  If not, see <https://www.gnu.org/licenses/>.
- *
- * @brief  Wallpaper settings WallSett structure
- * 
- * @author Michał Bąbik <michalb1981@o2.pl>
- */
+* @file  settstr.h
+* @copyright Copyright (C) 2019 Michał Bąbik
+*
+* This file is part of Wall Changer.
+*
+* Wall Changer is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation, either version 3 of the License, or
+* (at your option) any later version.
+*
+* Wall Changer is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with Wall Changer.  If not, see <https://www.gnu.org/licenses/>.
+*
+* @brief  Wallpaper settings WallSett structure and functions
+* 
+* @author Michał Bąbik <michalb1981@o2.pl>
+*/
 #ifndef SETTSTR_H
 #define SETTSTR_H
 #include <glib.h>
@@ -42,5 +42,7 @@ WallSett {
     uint64_t  i_hash;        /**< Last data hash */
 } WallSett;
 /*----------------------------------------------------------------------------*/
+void free_wall_sett (WallSett *ws_sett);
+/*----------------------------------------------------------------------------*/
 #endif
 
