@@ -19,9 +19,9 @@
  *
  * Wallpaper changing appliation.
  *
- * @date November 7, 2019
+ * @date November 8, 2019
  *
- * @version 1.1
+ * @version 1.1.1
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -825,7 +825,7 @@ activate (GtkApplication *app,
     GtkWidget     *gw_settings_widget; // Setings for wallpaper changing
 
     gw_window = gtk_application_window_new (app);
-    gtk_window_set_title (GTK_WINDOW (gw_window), "Wall Changer v1.1");
+    gtk_window_set_title (GTK_WINDOW (gw_window), "Wall Changer v1.1.1");
     gtk_window_set_default_size (GTK_WINDOW (gw_window), 1024, 768);
     g_signal_connect (gw_window, "delete-event",
                   G_CALLBACK (event_on_delete), dd_data);
@@ -908,21 +908,6 @@ activate (GtkApplication *app,
     gtk_widget_show_all (gw_window);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Free allocated memory.
- *
- * @param[out]  dd_data  Pointer to DialogData with all settings
- * @return      none
- */
-static void
-free_stuff (DialogData *dd_data)
-{
-    g_slist_free_full (dd_data->ws_sett->gsl_files, g_free);
-    g_free (dd_data->ws_sett->s_bgcmd);
-    g_free (dd_data->ws_sett->s_cfgfile);
-    g_free (dd_data->ws_sett->s_lastused);
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Application shutdown signal.
  *
@@ -934,7 +919,7 @@ static void
 shutdown (GtkApplication *app,
           DialogData     *dd_data)
 {
-    free_stuff (dd_data);
+    free_wall_sett (dd_data->ws_sett);
 }
 /*----------------------------------------------------------------------------*/
 /**
